@@ -326,6 +326,32 @@
 #define __NR_kexec_file_load            381
 #define __NR_io_pgetevents              382
 #define __NR_rseq                       383
+#define __NR_pkey_mprotect              384
+#define __NR_pkey_alloc                 385
+#define __NR_pkey_free                  386
+#define __NR_semtimedop                 392
+#define __NR_semget                     393
+#define __NR_semctl                     394
+#define __NR_shmget                     395
+#define __NR_shmctl                     396
+#define __NR_shmat                      397
+#define __NR_shmdt                      398
+#define __NR_msgget                     399
+#define __NR_msgsnd                     400
+#define __NR_msgrcv                     401
+#define __NR_msgctl                     402
+#define __NR_pidfd_send_signal          424
+#define __NR_io_uring_setup             425
+#define __NR_io_uring_enter             426
+#define __NR_io_uring_register          427
+#define __NR_open_tree		428
+#define __NR_move_mount		429
+#define __NR_fsopen		430
+#define __NR_fsconfig		431
+#define __NR_fsmount		432
+#define __NR_fspick		433
+#define __NR_pidfd_open		434
+#define __NR_clone3		435
 
 #define SYS_exit                         1
 #define SYS_fork                         2
@@ -654,4 +680,30 @@
 #define SYS_s390_sthyi                 380
 #define SYS_kexec_file_load            381
 #define SYS_io_pgetevents              382
-#define SYS_rseq                       383
\ No newline at end of file
+#define SYS_rseq                       383
+#define SYS_pkey_mprotect              384
+#define SYS_pkey_alloc                 385
+#define SYS_pkey_free                  386
+#define SYS_semtimedop                 392
+#define SYS_semget                     393
+#define SYS_semctl                     394
+#define SYS_shmget                     395
+#define SYS_shmctl                     396
+#define SYS_shmat                      397
+#define SYS_shmdt                      398
+#define SYS_msgget                     399
+#define SYS_msgsnd                     400
+#define SYS_msgrcv                     401
+#define SYS_msgctl                     402
+#define SYS_pidfd_send_signal          424
+#define SYS_io_uring_setup             425
+#define SYS_io_uring_enter             426
+#define SYS_io_uring_register          427
+#define SYS_open_tree		428
+#define SYS_move_mount		429
+#define SYS_fsopen		430
+#define SYS_fsconfig		431
+#define SYS_fsmount		432
+#define SYS_fspick		433
+#define SYS_pidfd_open		434
+#define SYS_clone3		435
\ No newline at end of file
